import { createRouter, createWebHashHistory, RouteRecordRaw } from "vue-router";

export const Layout = () => import("@/layout/index.vue");

// 静态路由
export const constantRoutes: RouteRecordRaw[] = [
  {
    path: "/redirect",
    component: Layout,
    meta: { hidden: true },
    children: [
      {
        path: "/redirect/:path(.*)",
        component: () => import("@/views/redirect/index.vue"),
      },
    ],
  },

  {
    path: "/login",
    component: () => import("@/views/login/index.vue"),
    meta: { hidden: true },
  },

  {
    path: "/",
    name: "/",
    component: Layout,
    redirect: "/process",
    children: [
      {
        path: "process",
        component: () => import("@/views/process/main.vue"),
        name: "process",

        meta: {
          title: "process",
          icon: "homepage",
        },
      },
      {
        path: "pro-steps",
        component: () => import("@/views/pro-steps/index.vue"),
        name: "pro-steps",
        meta: {
          title: "pro-steps",
          icon: "homepage",
          back: true,
        },
      },
    ],
  },

  {
    path: "/:pathMatch(.*)*", // 必备
    component: () => import("@/views/error-page/404.vue"),
  },
];

/**
 * 创建路由
 */
const router = createRouter({
  history: createWebHashHistory(),
  routes: constantRoutes,
  // 刷新时，滚动条位置还原
  scrollBehavior: () => ({ left: 0, top: 0 }),
});

/**
 * 重置路由
 */
export function resetRouter() {
  router.replace({ path: "/login" });
}

export default router;
